#! /usr/bin/env node

var _ = require('underscore');
var fs = require('fs');
var fileExists = require('file-exists');
var path = require('path');
var moduleFile = fs.realpathSync(__filename);
var moduleRoot = path.dirname(moduleFile);
var chalk = require('chalk');
var error = chalk.bgRed.white;
var yargs = require('yargs');

function getConfig() {
	var dir = path.join(process.cwd(), 'pz-templates', 'config.json');
	var config = {};
	if(fileExists(dir)) {
		config = require(dir) || {};
	} 
	
	return config;
}

function getPaths() {
	var config = getConfig();
	var paths = [];
	
	paths.push(path.join(process.cwd(), 'pz-templates'));
	if(config.paths) {
		paths = _.union(paths, config.paths);
	}
	paths.push(path.join(moduleRoot, 'pz-templates'));
	return paths;
}

function bind(action, moduleName) {
	if(!action || !moduleName) return; //fail silently

	var potentialPaths = getPaths();
    var pathsSearched = [];
    var foundPath = null;

    _.find(potentialPaths, function(relpath) {
        var fullpath = path.join(relpath, action, moduleName, 'index.js');
        if(fileExists(fullpath)) {
            foundPath = fullpath;
            return;
        } else {
            pathsSearched.push(fullpath);
        }
    });
    
    if(foundPath) {
        var Binder = require('./binders/' + action + '.js');
		var templateDir = path.dirname(foundPath);
        var options = require(templateDir);
		options.context = getConfig().context;
		options.paths = {
			templateDir: templateDir
		};
        var binder = new Binder(options);
    } else {
        console.log(error('Cound not find template:', action, moduleName));
        console.log(error('Where I looked:'));
        _.each(pathsSearched, function(path) {
            console.log(error('  ', path)); 
        });
    }
}

yargs.alias('c', 'create');
bind('create', yargs.argv.create);

yargs.alias('r', 'run');
bind('run', yargs.argv.run);

